"""
NewFunctionsPYC
~~~~~~~~~~

This module is for adding new functions to pycord
To make it easier for new people to get started on pycord

:copyright: (c) 2023-present Marciel404
:license: MIT, see LICENSE for more details.

:pycord-site: https://pycord.dev/ (English)
:pycord-discord-server: https://discord.gg/pycord (English)

:my-server: https://discord.gg/2UtE8tMyh5 (Portuguese)
"""

__name__ = "NewFunctionsPYC"
__version__ = "1.0.1"
__author__ = "Marciel404"
__license__ = "MIT"

from .embeds.embed import *
from .client.loader import *
from .commands.prefix import *
from .commands.slash import *
from .commands.hybrid import *

